# remirepo/fedora spec file for librdkafka
#
# Copyright (c) 2015-2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global libname      librdkafka
%global gh_commit    77a013b7a2611f7bdc091afa1e56b1a46d1c52f5
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     edenhill
%global gh_project   %{libname}
%global oldsoname    1
%global newsoname    101

%global upstream_version 1.7.0
#global upstream_prever  RC1

Name:    %{libname}%{oldsoname}php
Version: %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release: 1%{?dist}
Group:   System Environment/Libraries
Summary: Apache Kafka C/C++ client library

# librdkafka is BSD-2, pycrc is MIT, snappy/crc32 are BSD-3
License: BSD and MIT
URL:     https://github.com/%{gh_owner}/%{gh_project}
Source0: https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{upstream_version}%{?upstream_prever}-%{gh_short}.tar.gz

# Bump soname from 1 to 101 to allow parallel installation
Patch0:  %{libname}-soname.patch

BuildRequires:  libstdc++-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(RapidJSON)

%if 0%{?rhel} == 7
%global dtsenable source /opt/rh/devtoolset-7/enable
BuildRequires:  devtoolset-7-toolchain
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  python3


%description
librdkafka is a C library implementation of the Apache Kafka protocol,
containing both Producer and Consumer support.

It was designed with message delivery reliability and high performance
in mind, current figures exceed 800000 msgs/second for the producer
and 3 million msgs/second for the consumer.

%{name} is designed to be installed beside %{libname}
and only used by PHP binaries (rdkafka extension).


%package devel
Group:     Development/Libraries
Summary:   Development files for %{name}
Requires:  %{name}%{?_isa}  = %{version}-%{release}
Conflicts: %{libname}-devel < %{version}
Provides:  %{libname}-devel = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -qn %{gh_project}-%{gh_commit}
%patch0 -p1 -b .bump

mkdir rpmdocs
cp -pr examples rpmdocs/examples


%build
%{?dtsenable}
gcc --version

%configure \
    --enable-zlib \
    --enable-zstd \
    --enable-lz4 \
    --enable-lz4-ext \
    --enable-ssl \
    --enable-gssapi \
    --enable-sasl

make %{?_smp_mflags}


%install
%{?dtsenable}

make install DESTDIR=%{buildroot}

rm %{buildroot}%{_libdir}/*.a
rm %{buildroot}%{_libdir}/pkgconfig/*static.pc
# drop installed doc as all file included as %%license or %%doc in -devel
rm -r %{buildroot}%{_datadir}/doc/%{libname}


%if 0%{?fedora} < 28 && 0%{?rhel} < 8
%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE*
%{_libdir}/%{libname}.so.%{newsoname}
%{_libdir}/%{libname}++.so.%{newsoname}

%files devel
%doc *md
%doc rpmdocs/examples
%{_includedir}/%{libname}/
%{_libdir}/%{libname}.so
%{_libdir}/%{libname}++.so
%{_libdir}/pkgconfig/rdkafka.pc
%{_libdir}/pkgconfig/rdkafka++.pc


%changelog
* Mon May 10 2021 Remi Collet <remi@remirepo.net> - 1.7.0-1
- update to 1.7.0

* Thu Feb 25 2021 Remi Collet <remi@remirepo.net> - 1.6.1-1
- update to 1.6.1

* Wed Jan 27 2021 Remi Collet <remi@remirepo.net> - 1.6.0-1
- update to 1.6.0

* Wed Dec  9 2020 Remi Collet <remi@remirepo.net> - 1.5.3-1
- update to 1.5.3
- use rapidjson

* Tue Oct 20 2020 Remi Collet <remi@remirepo.net> - 1.5.2-1
- update to 1.5.2

* Mon Jul 20 2020 Remi Collet <remi@remirepo.net> - 1.5.0-1
- update to 1.5.0
- use GCC 6 on EL-6, GCC 7 on EL-7

* Sun Jun 21 2020 Remi Collet <remi@remirepo.net> - 1.4.4-1
- update to 1.4.4

* Wed Jun 10 2020 Remi Collet <remi@remirepo.net> - 1.4.2-2
- rename to librdkafka1php

* Wed May  6 2020 Remi Collet <remi@remirepo.net> - 1.4.2-1
- update to 1.4.2

* Fri Apr  3 2020 Remi Collet <remi@remirepo.net> - 1.4.0-1
- update to 1.4.0

* Wed Dec  4 2019 Remi Collet <remi@remirepo.net> - 1.3.0-1
- update to 1.3.0

* Tue Nov 12 2019 Remi Collet <remi@remirepo.net> - 1.2.2-1
- update to 1.2.2

* Wed Oct  9 2019 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0

* Tue Jun 25 2019 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0

* Sun Jun  2 2019 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Tue Mar 26 2019 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0
- add dependency on libzstd

* Wed Dec 12 2018 Remi Collet <remi@remirepo.net> - 0.11.6-2
- cleanup for EL-8

* Fri Oct 19 2018 Remi Collet <remi@remirepo.net> - 0.11.6-1
- update to 0.11.6

* Thu Jul 19 2018 Remi Collet <remi@remirepo.net> - 0.11.5-1
- update to 0.11.5

* Thu Mar 29 2018 Remi Collet <remi@remirepo.net> - 1.11.4-1
- update to 1.11.4

* Wed Dec  6 2017 Remi Collet <remi@remirepo.net> - 0.11.3-1
- update to 0.11.3

* Wed Oct 18 2017 Remi Collet <remi@remirepo.net> - 0.11.1-1
- update to 0.11.1

* Thu Oct  5 2017 Remi Collet <remi@remirepo.net> - 0.11.1~RC1-1
- update to 0.11.1-RC1

* Tue Aug  1 2017 Remi Collet <remi@remirepo.net> - 0.11.0-1
- update to 0.11.0

* Thu Jun 29 2017 Remi Collet <remi@remirepo.net> - 0.11.0~RC2-1
- update to 0.11.0-RC2

* Thu Jun 29 2017 Remi Collet <remi@remirepo.net> - 0.11.0~RC1-1
- update to 0.11.0-RC1
- open https://github.com/edenhill/librdkafka/issues/1290
  broken build on 32-bit architecture
- add upstream for i686 build

* Fri Apr 21 2017 Remi Collet <remi@remirepo.net> - 0.9.5-1
- update to 0.9.5 (no change since RC2)

* Wed Apr 12 2017 Remi Collet <remi@remirepo.net> - 0.9.5~RC2-1
- update to 0.9.5-RC2

* Mon Apr 10 2017 Remi Collet <remi@remirepo.net> - 0.9.5~RC1-1
- update to 0.9.5-RC1

* Mon Feb 27 2017 Remi Collet <remi@remirepo.net> - 0.9.4-1
- update to 0.9.4

* Fri Feb 24 2017 Remi Collet <remi@remirepo.net> - 0.9.4-0.3.RC2
- update to 0.9.4RC2 for test

* Fri Feb 17 2017 Remi Collet <remi@remirepo.net> - 0.9.4-0.2.RC1
- enable lz4

* Thu Feb 16 2017 Remi Collet <remi@remirepo.net> - 0.9.4-0.1.RC1
- update to 0.9.4RC1 for test

* Mon Jan 23 2017 Remi Collet <remi@fedoraproject.org> - 0.9.3-1
- update to 0.9.3

* Wed Nov  9 2016 Remi Collet <remi@fedoraproject.org> - 0.9.2-1
- update to 0.9.2

* Sun May 29 2016 Remi Collet <remi@fedoraproject.org> - 0.9.1-1
- update to 0.9.1

* Sat Jan  9 2016 Remi Collet <remi@fedoraproject.org> - 0.9.0-1
- update to 0.9.0
- add upstream patch for old glibc (RHEL-5)

* Thu May 14 2015 Remi Collet <remi@fedoraproject.org> - 0.8.6-1
- initial package
